@@ -1,4 +1,4 @@
-<?php // $Id: mod.php,v 1.80 2005/04/24 12:37:37 stronk7 Exp $
+<?php // $Id: mod.php,v 1.80.2.3 2005/10/09 19:38:57 skodak Exp $
 
 //  Moves, adds, updates, duplicates or deletes modules in a course
 
@@ -29,14 +29,29 @@
 
     if (isset($_POST["course"]) and confirm_sesskey()) {    // add or update form submitted
 
-        if (!$course = get_record("course", "id", $mod->course)) {
-            error("This course doesn't exist");
+        if (empty($mod->coursemodule)) { //add
+            if (! $course = get_record("course", "id", $mod->course)) {
+                error("This course doesn't exist");
+            }
+            $mod->instance = '';
+            $mod->coursemodule = '';
+        } else { //delete and update
+            if (! $cm = get_record("course_modules", "id", $mod->coursemodule)) {
+                error("This course module doesn't exist");
+            }
+
+            if (! $course = get_record("course", "id", $cm->course)) {
+                error("This course doesn't exist");
+            }
+            $mod->instance = $cm->instance;
+            $mod->coursemodule = $cm->id;
         }
 
         if (!isteacheredit($course->id)) {
             error("You can't modify this course!");
         }
-
+        
+        $mod->course = $course->id;
         $mod->modulename = clean_filename($mod->modulename);  // For safety
         $modlib = "$CFG->dirroot/mod/$mod->modulename/lib.php";
 
@@ -239,6 +254,10 @@
             error("This course module doesn't exist");
         }
 
+        if (!isteacheredit($cm->course)) {
+            error("You can't modify this course!");
+        }
+
         $cm->indent += $_GET['indent'];
 
         if ($cm->indent < 0) {
@@ -606,7 +625,7 @@
         $icon = "<img align=\"middle\" height=\"16\" width=\"16\" src=\"$CFG->modpixpath/$module->name/icon.gif\" alt=\"\" />&nbsp;";
 
         print_heading_with_help($pageheading, "mods", $module->name, $icon);
-        print_simple_box_start("center");
+        print_simple_box_start('center', '', '', 5, 'generalbox', $module->name);
         include_once($modform);
         print_simple_box_end();
 
