@@ -1,10 +1,10 @@
 <?PHP // $Id$ 
-      // block_course_list.php - created with Moodle 1.3.3 (2004052503)
+      // block_course_list.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005033100)
 
 
 $string['allcourses'] = 'Adminbrugere kan se alle kurser';
 $string['blockname'] = 'Kursusoversigt';
-$string['configadminview'] = 'ConfigAdminVisning';
+$string['configadminview'] = 'Hvad skal admins kunne se i kursusoversigtsblokken';
 $string['owncourses'] = 'Adminbrugere kan se egne kurser';
 
 ?>
